@@ -85,6 +85,7 @@ use G::Tools::KEGG_API;
 use G::Tools::PEC;
 use G::Tools::Statistics;
 use G::Tools::GMap;
+use G::Tools::WebServices;
 use G::SystemsBiology::PathwayAlignment;
 use G::SystemsBiology::KEGG;
 use G::SystemsBiology::BioLayout;
@@ -138,6 +139,7 @@ push(@EXPORT, @G::Tools::KEGG_API::EXPORT);
 push(@EXPORT, @G::Tools::PEC::EXPORT);
 push(@EXPORT, @G::Tools::Statistics::EXPORT);
 push(@EXPORT, @G::Tools::GMap::EXPORT);
+push(@EXPORT, @G::Tools::WebServices::EXPORT);
 push(@EXPORT, @G::SystemsBiology::PathwayAlignment::EXPORT);
 push(@EXPORT, @G::SystemsBiology::KEGG::EXPORT);
 push(@EXPORT, @G::SystemsBiology::BioLayout::EXPORT);
