@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: GenBankI.pm,v 1.1 2002/07/30 17:44:27 gaou Exp $
@@ -344,40 +342,4 @@ sub getnucs {
 
 }
 
-
-#::::::::::::::::::::::::::::::
-#          Perldoc
-#::::::::::::::::::::::::::::::
-
 1;
-
-__END__
-
-=head1 NAME
-
-G::IO::GenBankI
-
-=head1 SYNOPSIS
-
- use G::IO::GenBankI;
- @ISA = (G::IO::GenBankI);
-   
-=head1 DESCRIPTION
-
- GenBank input parser.
- Intended for internal use only.
-
-=back
-
-=head1 AUTHOR
-
-Kazuharu Arakawa, gaou@sfc.keio.ac.jp
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
-
-
-
