@@ -1,7 +1,7 @@
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: GCskew.pm,v 1.3 2002/08/16 15:03:36 gaou Exp $
@@ -32,14 +32,9 @@ use G::Tools::Graph;
 use G::Seq::Primitive;
 
 use strict;
-use Statistics::Descriptive;
-use Math::FFT;
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-our @ISA = qw(Exporter);
-
 our @EXPORT = qw(
 	     find_ori_ter
 	     gcskew
@@ -133,6 +128,7 @@ __DATA__
 
 
 sub find_ori_ter {
+    require Statistics::Descriptive;
     &opt_default(output=>"stdout", purine=>0, keto=>0, window=>4096);
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
@@ -147,6 +143,7 @@ sub find_ori_ter {
 
     my ($max, $min);
     if(length $lowpass){
+	require Math::FFT;
 	my $window = int($len / $power);
 	my @gcskew = gcskew($gb, -output=>"/dev/null", -window=>$window, -purine=>$purine, -keto=>$keto);
 
@@ -411,6 +408,9 @@ sub leading_strand {
 
 
 sub gcsi{
+    require Statistics::Descriptive;
+    require Math::FFT;
+
     opt_default(window=>4096);
     my @args = opt_get(@_);
     my $gb = opt_as_gb(shift @args);
@@ -890,7 +890,7 @@ sub gcwin  {
 
 
 
-=head2 query_strand 
+=head2 query_strand
 
   Name: query_strand   -   get the strand name (leading or lagging) from the given position
 
@@ -913,8 +913,8 @@ sub gcwin  {
     Kazuharu Arakawa (gaou@sfc.keio.ac.jp)
 
   History:
-    20020218-01 initial posting
     20070106-01 added CDS option
+    20020218-01 initial posting
 
 =cut
 
