@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Operon.pm,v 1.2 2002/07/30 17:40:56 gaou Exp $
@@ -35,16 +33,11 @@ use G::Messenger;
 use LWP::Simple;
 
 use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
-
-
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter);
-@EXPORT = qw(
-	     set_operon
+our @EXPORT = qw(
+		 set_operon
 );
 
 
