@@ -1,9 +1,7 @@
-#!/usr/bin/env perl
-
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # This file is part of G-language Genome Analysis Environment package
 #
-#     Copyright (C) 2001-2007 Keio University
+#     Copyright (C) 2001-2008 Keio University
 #:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
 # 
 #   $Id: Reader.pm,v 1.8 2002/04/01 14:19:54 t98901ka Exp $
@@ -30,18 +28,14 @@ package G::SystemsBiology::Interaction;
 
 use SubOpt;
 use G::Messenger;
-#use G::SystemsBiology::EcellReader;
 use G::Tools::GPAC;
-use strict;
-use vars qw($VERSION @ISA @EXPORT @EXPORT_OK);
 
+use strict;
+use base qw(Exporter);
 use SelfLoader;
 
-require Exporter;
-
-@ISA = qw(Exporter AutoLoader);
-@EXPORT = qw(
-	     substance_layout2	     
+our @EXPORT = qw(
+		 substance_layout2	     
 );
 
 #::::::::::::::::::::::::::::::
@@ -238,37 +232,4 @@ sub substance_layout2{
 
 
 
-sub DESTROY {
-    my $self = shift;
-}
-
 1;
-__END__
-# Below is the stub of documentation for your module. You better edit it!
-
-=head1 NAME
-
-G::Ecell::Interaction - Perl extension for blah blah blah
-
-=head1 SYNOPSIS
-
-  use G::Ecell::Interaction;
-  blah blah blah
-
-=head1 DESCRIPTION
-
-Stub documentation for G::Ecell::Interaction was created by h2xs. It looks like the
-author of the extension was negligent enough to leave the stub
-unedited.
-
-Blah blah blah.
-
-=head1 AUTHOR
-
-Seira Nakamura, gaou@g-language.org
-
-=head1 SEE ALSO
-
-perl(1).
-
-=cut
